# -*- coding: UTF-8 -*-
from horus import backend
from os.path import isdir, isfile
from os import system
from creole import parsedico
from creole.eosfunc import test_vz
from time import sleep
import ftplib

dico = parsedico.parse_dico()

def test_create_group():
    assert backend.add_group('tgroupe')
    assert backend.add_group('tgroupe2')

def test_create_share():
    assert backend.add_share('tgroupe2', 'tgroupe2')

def test_create_user():
    assert backend.add_user('tuser', 'tgroupe')
    assert 'DomainUsers' in backend.get_user_groups('tuser')
    assert backend.mod_password('tuser', 'tuser')

def test_inscription():
    assert backend.inscription('tuser', 'tgroupe2')
    assert isdir('/home/tuser/.ftp/tgroupe2')

def test_smb_perso():
    if not test_vz():
        system('mkdir -p /tmp/home')
        assert system('smbmount //127.0.0.1/tuser /tmp/home -o username=tuser,password=tuser') == 0
        system('touch /tmp/home/fichier.txt')
        assert isfile('/tmp/home/fichier.txt')
        system('rm -f /tmp/home/fichier.txt')
        assert not isfile('/tmp/home/fichier.txt')
        # test antivirus temps réel
        if dico['smb_vscan'] == 'oui':
            system("""echo 'X5O!P%@AP[4\PZX54(P^)7CC)7}$EICAR-STANDARD-ANTIVIRUS-TEST-FILE!$H+H*' > /tmp/home/virus.txt""")
            sleep(1)
            assert not isfile('/tmp/home/virus.txt')
            system('rm -f /tmp/home/virus.txt')
        system('umount /tmp/home/')

def test_smb_share():
    if not test_vz():
        system('mkdir -p /tmp/tgroupe2')
        assert system('smbmount //127.0.0.1/tgroupe2 /tmp/tgroupe2 -o username=tuser,password=tuser') == 0
        system('touch /tmp/tgroupe2/fichier.txt')
        assert isfile('/tmp/tgroupe2/fichier.txt')
        system('rm -f /tmp/tgroupe2/fichier.txt')
        assert not isfile('/tmp/tgroupe2/fichier.txt')
        system('umount /tmp/tgroupe2')

def test_profils():
    # profil à la création
    assert backend.get_attr('tuser', 'sambaProfilePath') == []
    # modification
    backend.mod_user('tuser', profile="obligatoire")
    assert backend.get_attr('tuser', 'sambaProfilePath') == ["\\\\%(smb_netbios_name)s\\netlogon\\profil" % dico]

def test_quotas():
    # quotas à la création
    assert backend.get_quota('tuser') == 0
    # modification de quotas
    backend.set_quota('tuser', 50)
    assert backend.get_quota('tuser') == 50

def test_ftp_user():
    if dico['ftp_perso'] == 'oui':
        session = ftplib.FTP('127.0.0.1', 'tuser', 'tuser')
        session.quit()

def test_del_user():
    assert backend.del_user('tuser', remove_data=True)
    assert not isdir('/home/tuser')

def test_del_group():
    assert backend.del_group('tgroupe')
    assert backend.del_group('tgroupe2')
